@@ -1,20 +1,21 @@
 // SPDX-FileCopyrightText: 2020 Jonah Brüchert <jbb@kaidan.im>
 //
-// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
+// SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #pragma once
 
 #include <KPeople/PersonsModel>
+#include <KContacts/PhoneNumber>
 #include <QObject>
 
-#include <unordered_map>
-
-#include "phonenumber.h"
+#include "phonenumberutils.h"
 
 class ContactPhoneNumberMapper : public QObject
 {
     Q_OBJECT
 
+    explicit ContactPhoneNumberMapper();
+
 public:
     /**
      * @brief Returns the KPeople URI belonging to phone number,
@@ -23,26 +24,31 @@ public:
      * @param phone number
      * @return the uri belonging to the phone number
      */
-    QString uriForNumber(const PhoneNumber &phoneNumber) const;
+    inline QString uriForNumber(const QString &phoneNumber) const {
+        return m_numberToUri.value(PhoneNumberUtils::normalize(phoneNumber));
+    }
 
     static ContactPhoneNumberMapper &instance();
 
-Q_SIGNALS:
+signals:
     /**
      * @brief contactsChanged is emitted whenever the ContactMapper has new data,
      * because a contact was added to KPeople
      * @param list of affected numbers
      */
-    void contactsChanged(const QVector<PhoneNumber> phoneNumber);
+    void contactsChanged(const QVector<QString> phoneNumbers);
 
-private Q_SLOTS:
+private slots:
     void processRows(const int first, const int last);
 
-private:
-    explicit ContactPhoneNumberMapper();
-    [[nodiscard]] std::string normalizeNumber(const std::string &numberString) const;
+public slots:
+    /**
+     * @brief Scans all persons known to kpeople for phone numbers
+     * This must be run before anything useful can be done with the ContactMapper
+     */
+    void performInitialScan();
 
+private:
     KPeople::PersonsModel *m_model;
-    QHash<PhoneNumber, QString> m_numberToUri;
-    std::string m_country;
+    QHash<QString, QString> m_numberToUri;
 };
